@@ -326,6 +326,16 @@ function check_configurable_variables($con, $table, $items_json_array){
 		}else{
 			$default = "";
 		}
+		if(isset($attr["size"])){
+			$size = $attr["size"];
+		}else{
+			$size = "";
+		}
+		if($size != ""){
+		    $varchar_size = $size;
+		}else{
+		    $varchar_size = "255";
+		}
 
 		$qf = "SHOW FULL COLUMNS FROM $table WHERE Field='$col'";
 		// If the field is not present, create it.
@@ -347,7 +357,8 @@ function check_configurable_variables($con, $table, $items_json_array){
 				break;
 			case "fqdn":
 			case "string":
-				$qadd = "ALTER TABLE $table ADD $col varchar(255) NOT NULL default '$default'";
+			case "ip_list":
+				$qadd = "ALTER TABLE $table ADD $col varchar($varchar_size) NOT NULL default '$default'";
 				$radd = mysqli_query($con, $qadd)or die("Cannot execute query: \"$qadd\" line ".__LINE__." in file ".__FILE__.", mysql said: ".mysqli_error($con));
 				break;
 			default:
@@ -387,8 +398,8 @@ function check_configurable_variables($con, $table, $items_json_array){
 				break;
 			case "fqdn":
 			case "string":
-				if($a_type != "varchar(255)" || $a_def != $default){
-					$qadd = "ALTER TABLE $table CHANGE $col $col varchar(255) NOT NULL default '$default'";
+				if($a_type != "varchar($varchar_size)" || $a_def != $default){
+					$qadd = "ALTER TABLE $table CHANGE $col $col varchar($varchar_size) NOT NULL default '$default'";
 					$radd = mysqli_query($con, $qadd)or die("Cannot execute query: \"$qadd\" line ".__LINE__." in file ".__FILE__.", mysql said: ".mysqli_error($con));
                                         echo "fix ";
 				}
